aboutsummaryrefslogtreecommitdiff
path: root/src/coins.h
diff options
context:
space:
mode:
authorJohn Newbery <john@johnnewbery.com>2020-03-23 10:45:34 -0400
committerJohn Newbery <john@johnnewbery.com>2020-04-21 14:19:15 -0400
commit21fa0a44abe8c1b5c452e097eab20cf0ae988805 (patch)
tree4d3c982ba590833e9e949c55ec504e3b65fdc1bf /src/coins.h
parent2685c214cce4b07695273503e60350e3f05fe3e2 (diff)
downloadbitcoin-21fa0a44abe8c1b5c452e097eab20cf0ae988805.tar.xz
[docs] use consistent naming for possible_overwrite
And other general comment improvements for adding coins.
Diffstat (limited to 'src/coins.h')
-rw-r--r--src/coins.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/coins.h b/src/coins.h
index d5484bcf65..6cfe368331 100644
--- a/src/coins.h
+++ b/src/coins.h
@@ -284,10 +284,10 @@ public:
const Coin& AccessCoin(const COutPoint &output) const;
/**
* Add a coin. Set potential_overwrite to true if an unspent version may
* already exist in the cache.
*/
- void AddCoin(const COutPoint& outpoint, Coin&& coin, bool potential_overwrite);
+ void AddCoin(const COutPoint& outpoint, Coin&& coin, bool possible_overwrite);
/**
* Spend a coin. Pass moveto in order to get the deleted data.
@@ -284,10 +284,10 @@ public:
const Coin& AccessCoin(const COutPoint &output) const;
/**
- * Add a coin. Set potential_overwrite to true if an unspent version may
+ * Add a coin. Set possible_overwrite to true if an unspent version may
* already exist in the cache.
*/